@@ -15,6 +15,6 @@
 ;    You should have received a copy of the GNU General Public License
 ;    along with TwinLisp; if not, write to the Free Software
 ;    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-(in-package "TWINLISP")
+(cl:in-package "TWINLISP")
 ; copying methods
-(defgeneric _copy_ (obj) (:method ((obj t)) obj))
+(cl:defgeneric _copy_ (obj) (:method ((obj cl:t)) obj))
