@@ -23,7 +23,7 @@
  "_COPY_" "_DEEPCOPY_" ; export types' symbols
  "_SLICE_" "_ITERATOR_" "_LIST-ITERATOR_" "_SEQUENCE-ITERATOR_" ; export container creation funcs
  "_MAKE-SLICE_" "_MAKE-HASH-TABLE_" "_MAKE-VECTOR_" ; export containers' methods
- "LEN" "_GETITEM_" "(SETF _GETITEM_)" "INDEX" "ITER" "EXTEND" "INSERT" "TL-POP" "TL-COUNT" "TL-APPEND" "TL-REMOVE" "TKEYS" "TVALUES" "TITEMS" "HAS_KEY" ; export error conditions
+ "LEN" "_GETITEM_" "(SETF _GETITEM_)" "INDEX" "ITER" "EXTEND" "INSERT" "UPDATE" "TL-POP" "TL-COUNT" "TL-APPEND" "TL-REMOVE" "TKEYS" "TVALUES" "TITEMS" "HAS_KEY" ; export error conditions
  "INDEX-ERROR" "CONTAINER" ; "INDEX" is exported above
  "NULL-LIST-ERROR"))
 (use-package "TL")
